/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.sqladmin.model;

import com.google.api.client.json.GenericJson;

/**
 * Database instance settings.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud SQL Administration API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Settings extends GenericJson {

  /**
   * The activation policy for this instance. This specifies when the instance should be activated
   * and is applicable only when the instance state is RUNNABLE. This can be one of the following.
   * ALWAYS: The instance should always be active. NEVER: The instance should never be activated.
   * ON_DEMAND: The instance is activated upon receiving requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String activationPolicy;

  /**
   * The AppEngine app ids that can access this instance.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> authorizedGaeApplications;

  /**
   * The daily backup configuration for the instance.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<BackupConfiguration> backupConfiguration;

  static {
    // hack to force ProGuard to consider BackupConfiguration used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(BackupConfiguration.class);
  }

  /**
   * This is always sql#settings.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The pricing plan for this instance. This can be either PER_USE or PACKAGE.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String pricingPlan;

  /**
   * The type of replication this instance uses. This can be either ASYNCHRONOUS or SYNCHRONOUS.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String replicationType;

  /**
   * The tier of service for this instance, for example D1, D2. For more information, see pricing.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String tier;

  /**
   * The activation policy for this instance. This specifies when the instance should be activated
   * and is applicable only when the instance state is RUNNABLE. This can be one of the following.
   * ALWAYS: The instance should always be active. NEVER: The instance should never be activated.
   * ON_DEMAND: The instance is activated upon receiving requests.
   * The value returned may be {@code null}.
   */
  public String getActivationPolicy() {
    return activationPolicy;
  }

  /**
   * The activation policy for this instance. This specifies when the instance should be activated
   * and is applicable only when the instance state is RUNNABLE. This can be one of the following.
   * ALWAYS: The instance should always be active. NEVER: The instance should never be activated.
   * ON_DEMAND: The instance is activated upon receiving requests.
   * The value set may be {@code null}.
   */
  public Settings setActivationPolicy(String activationPolicy) {
    this.activationPolicy = activationPolicy;
    return this;
  }

  /**
   * The AppEngine app ids that can access this instance.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getAuthorizedGaeApplications() {
    return authorizedGaeApplications;
  }

  /**
   * The AppEngine app ids that can access this instance.
   * The value set may be {@code null}.
   */
  public Settings setAuthorizedGaeApplications(java.util.List<String> authorizedGaeApplications) {
    this.authorizedGaeApplications = authorizedGaeApplications;
    return this;
  }

  /**
   * The daily backup configuration for the instance.
   * The value returned may be {@code null}.
   */
  public java.util.List<BackupConfiguration> getBackupConfiguration() {
    return backupConfiguration;
  }

  /**
   * The daily backup configuration for the instance.
   * The value set may be {@code null}.
   */
  public Settings setBackupConfiguration(java.util.List<BackupConfiguration> backupConfiguration) {
    this.backupConfiguration = backupConfiguration;
    return this;
  }

  /**
   * This is always sql#settings.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * This is always sql#settings.
   * The value set may be {@code null}.
   */
  public Settings setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The pricing plan for this instance. This can be either PER_USE or PACKAGE.
   * The value returned may be {@code null}.
   */
  public String getPricingPlan() {
    return pricingPlan;
  }

  /**
   * The pricing plan for this instance. This can be either PER_USE or PACKAGE.
   * The value set may be {@code null}.
   */
  public Settings setPricingPlan(String pricingPlan) {
    this.pricingPlan = pricingPlan;
    return this;
  }

  /**
   * The type of replication this instance uses. This can be either ASYNCHRONOUS or SYNCHRONOUS.
   * The value returned may be {@code null}.
   */
  public String getReplicationType() {
    return replicationType;
  }

  /**
   * The type of replication this instance uses. This can be either ASYNCHRONOUS or SYNCHRONOUS.
   * The value set may be {@code null}.
   */
  public Settings setReplicationType(String replicationType) {
    this.replicationType = replicationType;
    return this;
  }

  /**
   * The tier of service for this instance, for example D1, D2. For more information, see pricing.
   * The value returned may be {@code null}.
   */
  public String getTier() {
    return tier;
  }

  /**
   * The tier of service for this instance, for example D1, D2. For more information, see pricing.
   * The value set may be {@code null}.
   */
  public Settings setTier(String tier) {
    this.tier = tier;
    return this;
  }

}
